You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@struts.apache.org by lu...@apache.org on 2011/12/02 17:33:45 UTC

svn commit: r1209569 [4/50] - in /struts/struts2/branches/STRUTS_3_X: apps/blank/src/main/java/example/ apps/blank/src/test/java/example/ apps/jboss-blank/src/main/java/example/ apps/jboss-blank/src/test/java/example/ apps/mailreader/src/main/java/mail...

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/MergeIterator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/MergeIterator.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/MergeIterator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/MergeIterator.java Fri Dec  2 16:33:03 2011
@@ -32,9 +32,9 @@ import org.apache.struts2.util.MergeIter
 import org.apache.struts2.views.annotations.StrutsTag;
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/OptGroup.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/OptGroup.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/OptGroup.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/OptGroup.java Fri Dec  2 16:33:03 2011
@@ -31,11 +31,11 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.views.annotations.StrutsTag;
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 
-import com.opensymphony.xwork2.inject.Container;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.inject.Container;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/OptionTransferSelect.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/OptionTransferSelect.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/OptionTransferSelect.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/OptionTransferSelect.java Fri Dec  2 16:33:03 2011
@@ -30,9 +30,9 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.views.annotations.StrutsTag;
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Param.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Param.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Param.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Param.java Fri Dec  2 16:33:03 2011
@@ -27,7 +27,7 @@ import org.apache.struts2.views.annotati
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 import org.apache.struts2.StrutsException;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Password.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Password.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Password.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Password.java Fri Dec  2 16:33:03 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.views.annotations.StrutsTag;
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Property.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Property.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Property.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Property.java Fri Dec  2 16:33:03 2011
@@ -21,9 +21,9 @@
 
 package org.apache.struts2.components;
 
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import org.apache.commons.lang.StringEscapeUtils;
 import org.apache.struts2.views.annotations.StrutsTag;
 import org.apache.struts2.views.annotations.StrutsTagAttribute;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Push.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Push.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Push.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Push.java Fri Dec  2 16:33:03 2011
@@ -26,7 +26,7 @@ import java.io.Writer;
 import org.apache.struts2.views.annotations.StrutsTag;
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Radio.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Radio.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Radio.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Radio.java Fri Dec  2 16:33:03 2011
@@ -26,7 +26,7 @@ import javax.servlet.http.HttpServletRes
 
 import org.apache.struts2.views.annotations.StrutsTag;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Reset.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Reset.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Reset.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Reset.java Fri Dec  2 16:33:03 2011
@@ -21,7 +21,7 @@
 
 package org.apache.struts2.components;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 import org.apache.struts2.views.annotations.StrutsTag;
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Select.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Select.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Select.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Select.java Fri Dec  2 16:33:03 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.views.annotations.StrutsTag;
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/ServletUrlRenderer.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/ServletUrlRenderer.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/ServletUrlRenderer.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/ServletUrlRenderer.java Fri Dec  2 16:33:03 2011
@@ -21,12 +21,12 @@
 
 package org.apache.struts2.components;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.config.entities.ActionConfig;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.config.entities.ActionConfig;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import org.apache.struts2.StrutsException;
 import org.apache.struts2.dispatcher.mapper.ActionMapper;
 import org.apache.struts2.dispatcher.mapper.ActionMapping;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Set.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Set.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Set.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Set.java Fri Dec  2 16:33:03 2011
@@ -26,7 +26,7 @@ import java.io.Writer;
 import org.apache.struts2.views.annotations.StrutsTag;
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Submit.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Submit.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Submit.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Submit.java Fri Dec  2 16:33:03 2011
@@ -29,9 +29,9 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.views.annotations.StrutsTag;
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Text.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Text.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Text.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Text.java Fri Dec  2 16:33:03 2011
@@ -21,9 +21,9 @@
 
 package org.apache.struts2.components;
 
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import org.apache.commons.lang.StringUtils;
 import org.apache.struts2.util.TextProviderHelper;
 import org.apache.struts2.views.annotations.StrutsTag;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/TextArea.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/TextArea.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/TextArea.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/TextArea.java Fri Dec  2 16:33:03 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.views.annotations.StrutsTag;
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/TextField.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/TextField.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/TextField.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/TextField.java Fri Dec  2 16:33:03 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.views.annotations.StrutsTag;
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Token.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Token.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Token.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/Token.java Fri Dec  2 16:33:03 2011
@@ -29,7 +29,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.views.annotations.StrutsTag;
 import org.apache.struts2.util.TokenHelper;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/UIBean.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/UIBean.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/UIBean.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/UIBean.java Fri Dec  2 16:33:03 2011
@@ -41,11 +41,11 @@ import org.apache.struts2.components.tem
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 import org.apache.struts2.views.util.ContextUtil;
 
-import com.opensymphony.xwork2.config.ConfigurationException;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.config.ConfigurationException;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * UIBean is the standard superclass of all Struts UI componentns.

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/URL.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/URL.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/URL.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/URL.java Fri Dec  2 16:33:03 2011
@@ -30,10 +30,10 @@ import org.apache.struts2.StrutsConstant
 import org.apache.struts2.views.annotations.StrutsTag;
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/UpDownSelect.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/UpDownSelect.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/UpDownSelect.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/UpDownSelect.java Fri Dec  2 16:33:03 2011
@@ -30,9 +30,9 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.views.annotations.StrutsTag;
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/UrlProvider.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/UrlProvider.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/UrlProvider.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/UrlProvider.java Fri Dec  2 16:33:03 2011
@@ -20,7 +20,7 @@
  */
 package org.apache.struts2.components;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/template/BaseTemplateEngine.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/template/BaseTemplateEngine.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/template/BaseTemplateEngine.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/template/BaseTemplateEngine.java Fri Dec  2 16:33:03 2011
@@ -21,9 +21,9 @@
 
 package org.apache.struts2.components.template;
 
-import com.opensymphony.xwork2.util.ClassLoaderUtil;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.ClassLoaderUtil;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 import java.io.File;
 import java.io.FileInputStream;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/template/FreemarkerTemplateEngine.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/template/FreemarkerTemplateEngine.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/template/FreemarkerTemplateEngine.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/template/FreemarkerTemplateEngine.java Fri Dec  2 16:33:03 2011
@@ -33,13 +33,13 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.ServletActionContext;
 import org.apache.struts2.views.freemarker.FreemarkerManager;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.ClassLoaderUtil;
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.ClassLoaderUtil;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 import freemarker.template.Configuration;
 import freemarker.template.SimpleHash;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/template/JspTemplateEngine.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/template/JspTemplateEngine.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/template/JspTemplateEngine.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/template/JspTemplateEngine.java Fri Dec  2 16:33:03 2011
@@ -23,19 +23,18 @@ package org.apache.struts2.components.te
 
 import java.util.List;
 
-import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import javax.servlet.jsp.PageContext;
 
-import com.opensymphony.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.inject.Inject;
 import org.apache.struts2.ServletActionContext;
 import org.apache.struts2.StrutsConstants;
 import org.apache.struts2.components.Include;
 import org.apache.struts2.components.UIBean;
 
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * JSP based template engine.

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/template/TemplateEngineManager.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/template/TemplateEngineManager.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/template/TemplateEngineManager.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/template/TemplateEngineManager.java Fri Dec  2 16:33:03 2011
@@ -26,9 +26,9 @@ import java.util.HashMap;
 import java.util.Map;
 import java.util.Set;
 
-import com.opensymphony.xwork2.config.ConfigurationException;
-import com.opensymphony.xwork2.inject.Container;
-import com.opensymphony.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.config.ConfigurationException;
+import org.apache.struts2.xwork2.inject.Container;
+import org.apache.struts2.xwork2.inject.Inject;
 
 /**
  * The TemplateEngineManager will return a template engine for the template

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/template/TemplateRenderingContext.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/template/TemplateRenderingContext.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/template/TemplateRenderingContext.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/template/TemplateRenderingContext.java Fri Dec  2 16:33:03 2011
@@ -26,7 +26,7 @@ import java.util.Map;
 
 import org.apache.struts2.components.UIBean;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * Context used when rendering templates.

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/template/VelocityTemplateEngine.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/template/VelocityTemplateEngine.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/template/VelocityTemplateEngine.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/components/template/VelocityTemplateEngine.java Fri Dec  2 16:33:03 2011
@@ -32,13 +32,12 @@ import javax.servlet.http.HttpServletRes
 
 import org.apache.struts2.ServletActionContext;
 import org.apache.struts2.views.velocity.VelocityManager;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import org.apache.velocity.app.VelocityEngine;
 import org.apache.velocity.context.Context;
 
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-
 /**
  * Velocity based template engine.
  */

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/config/BeanSelectionProvider.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/config/BeanSelectionProvider.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/config/BeanSelectionProvider.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/config/BeanSelectionProvider.java Fri Dec  2 16:33:03 2011
@@ -32,27 +32,30 @@ import org.apache.struts2.dispatcher.mul
 import org.apache.struts2.views.freemarker.FreemarkerManager;
 import org.apache.struts2.views.velocity.VelocityManager;
 
-import com.opensymphony.xwork2.ActionProxyFactory;
-import com.opensymphony.xwork2.ObjectFactory;
-import com.opensymphony.xwork2.TextProvider;
-import com.opensymphony.xwork2.UnknownHandlerManager;
-import com.opensymphony.xwork2.config.Configuration;
-import com.opensymphony.xwork2.config.ConfigurationException;
-import com.opensymphony.xwork2.config.ConfigurationProvider;
-import com.opensymphony.xwork2.conversion.ObjectTypeDeterminer;
-import com.opensymphony.xwork2.conversion.impl.XWorkConverter;
-import com.opensymphony.xwork2.inject.Container;
-import com.opensymphony.xwork2.inject.ContainerBuilder;
-import com.opensymphony.xwork2.inject.Context;
-import com.opensymphony.xwork2.inject.Factory;
-import com.opensymphony.xwork2.inject.Scope;
-import com.opensymphony.xwork2.util.*;
-import com.opensymphony.xwork2.util.location.LocatableProperties;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.util.reflection.ReflectionContextFactory;
-import com.opensymphony.xwork2.util.reflection.ReflectionProvider;
-import com.opensymphony.xwork2.validator.ActionValidatorManager;
+import org.apache.struts2.xwork2.ActionProxyFactory;
+import org.apache.struts2.xwork2.ObjectFactory;
+import org.apache.struts2.xwork2.TextProvider;
+import org.apache.struts2.xwork2.UnknownHandlerManager;
+import org.apache.struts2.xwork2.config.Configuration;
+import org.apache.struts2.xwork2.config.ConfigurationException;
+import org.apache.struts2.xwork2.config.ConfigurationProvider;
+import org.apache.struts2.xwork2.conversion.ObjectTypeDeterminer;
+import org.apache.struts2.xwork2.conversion.impl.XWorkConverter;
+import org.apache.struts2.xwork2.inject.Container;
+import org.apache.struts2.xwork2.inject.ContainerBuilder;
+import org.apache.struts2.xwork2.inject.Context;
+import org.apache.struts2.xwork2.inject.Factory;
+import org.apache.struts2.xwork2.inject.Scope;
+import org.apache.struts2.xwork2.util.ClassLoaderUtil;
+import org.apache.struts2.xwork2.util.LocalizedTextUtil;
+import org.apache.struts2.xwork2.util.ValueStackFactory;
+import org.apache.struts2.xwork2.util.location.LocatableProperties;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.reflection.ReflectionContextFactory;
+import org.apache.struts2.xwork2.util.reflection.ReflectionProvider;
+import org.apache.struts2.xwork2.validator.ActionValidatorManager;
+import org.apache.struts2.xwork2.util.PatternMatcher;
 
 /**
  * Selects the implementations of key framework extension points, using the loaded
@@ -72,19 +75,19 @@ import com.opensymphony.xwork2.validator
  *     <th>Description</th>
  *   </tr>
  *   <tr>
- *     <td>com.opensymphony.xwork2.ObjectFactory</td>
+ *     <td>org.apache.struts2.xwork2.ObjectFactory</td>
  *     <td>struts.objectFactory</td>
  *     <td>singleton</td>
  *     <td>Creates actions, results, and interceptors</td>
  *   </tr>
  *   <tr>
- *     <td>com.opensymphony.xwork2.ActionProxyFactory</td>
+ *     <td>org.apache.struts2.xwork2.ActionProxyFactory</td>
  *     <td>struts.actionProxyFactory</td>
  *     <td>singleton</td>
  *     <td>Creates the ActionProxy</td>
  *   </tr>
  *   <tr>
- *     <td>com.opensymphony.xwork2.util.ObjectTypeDeterminer</td>
+ *     <td>org.apache.struts2.xwork2.util.ObjectTypeDeterminer</td>
  *     <td>struts.objectTypeDeterminer</td>
  *     <td>singleton</td>
  *     <td>Determines what the key and element class of a Map or Collection should be</td>
@@ -114,38 +117,38 @@ import com.opensymphony.xwork2.validator
  *     <td>Loads and processes Velocity templates</td>
  *   </tr>
  *   <tr>
- *     <td>com.opensymphony.xwork2.validator.ActionValidatorManager</td>
+ *     <td>org.apache.struts2.xwork2.validator.ActionValidatorManager</td>
  *     <td>struts.actionValidatorManager</td>
  *     <td>singleton</td>
  *     <td>Main interface for validation managers (regular and annotation based).  Handles both the loading of
  *         configuration and the actual validation (since 2.1)</td>
  *   </tr>
  *   <tr>
- *     <td>com.opensymphony.xwork2.util.ValueStackFactory</td>
+ *     <td>org.apache.struts2.xwork2.util.ValueStackFactory</td>
  *     <td>struts.valueStackFactory</td>
  *     <td>singleton</td>
  *     <td>Creates value stacks (since 2.1)</td>
  *   </tr>
  *   <tr>
- *     <td>com.opensymphony.xwork2.reflection.ReflectionProvider</td>
+ *     <td>org.apache.struts2.xwork2.reflection.ReflectionProvider</td>
  *     <td>struts.reflectionProvider</td>
  *     <td>singleton</td>
  *     <td>Provides reflection services, key place to plug in a custom expression language (since 2.1)</td>
  *   </tr>
  *   <tr>
- *     <td>com.opensymphony.xwork2.reflection.ReflectionContextFactory</td>
+ *     <td>org.apache.struts2.xwork2.reflection.ReflectionContextFactory</td>
  *     <td>struts.reflectionContextFactory</td>
  *     <td>singleton</td>
  *     <td>Creates reflection context maps used for reflection and expression language operations (since 2.1)</td>
  *   </tr>
  *   <tr>
- *     <td>com.opensymphony.xwork2.config.PackageProvider</td>
+ *     <td>org.apache.struts2.xwork2.config.PackageProvider</td>
  *     <td>N/A</td>
  *     <td>singleton</td>
  *     <td>All beans registered as PackageProvider implementations will be automatically included in configuration building (since 2.1)</td>
  *   </tr>
  *   <tr>
- *     <td>com.opensymphony.xwork2.util.PatternMatcher</td>
+ *     <td>org.apache.struts2.xwork2.util.PatternMatcher</td>
  *     <td>struts.patternMatcher</td>
  *     <td>singleton</td>
  *     <td>Matches patterns, such as action names, generally used in configuration (since 2.1)</td>

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/config/DefaultPropertiesProvider.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/config/DefaultPropertiesProvider.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/config/DefaultPropertiesProvider.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/config/DefaultPropertiesProvider.java Fri Dec  2 16:33:03 2011
@@ -21,10 +21,10 @@
 
 package org.apache.struts2.config;
 
-import com.opensymphony.xwork2.config.Configuration;
-import com.opensymphony.xwork2.config.ConfigurationException;
-import com.opensymphony.xwork2.inject.ContainerBuilder;
-import com.opensymphony.xwork2.util.location.LocatableProperties;
+import org.apache.struts2.xwork2.config.Configuration;
+import org.apache.struts2.xwork2.config.ConfigurationException;
+import org.apache.struts2.xwork2.inject.ContainerBuilder;
+import org.apache.struts2.xwork2.util.location.LocatableProperties;
 
 /**
  * Loads the default properties, separate from the usual struts.properties loading

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/config/DefaultSettings.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/config/DefaultSettings.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/config/DefaultSettings.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/config/DefaultSettings.java Fri Dec  2 16:33:03 2011
@@ -27,9 +27,8 @@ import java.util.StringTokenizer;
 
 import org.apache.struts2.StrutsConstants;
 
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/config/LegacyPropertiesConfigurationProvider.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/config/LegacyPropertiesConfigurationProvider.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/config/LegacyPropertiesConfigurationProvider.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/config/LegacyPropertiesConfigurationProvider.java Fri Dec  2 16:33:03 2011
@@ -25,16 +25,15 @@ import java.util.Iterator;
 import java.util.Locale;
 import java.util.StringTokenizer;
 
-import com.opensymphony.xwork2.config.Configuration;
-import com.opensymphony.xwork2.config.ConfigurationException;
-import com.opensymphony.xwork2.config.ConfigurationProvider;
-import com.opensymphony.xwork2.inject.ContainerBuilder;
-import com.opensymphony.xwork2.inject.Context;
-import com.opensymphony.xwork2.inject.Factory;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.location.LocatableProperties;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.config.Configuration;
+import org.apache.struts2.xwork2.config.ConfigurationException;
+import org.apache.struts2.xwork2.config.ConfigurationProvider;
+import org.apache.struts2.xwork2.inject.ContainerBuilder;
+import org.apache.struts2.xwork2.inject.Context;
+import org.apache.struts2.xwork2.inject.Factory;
+import org.apache.struts2.xwork2.util.location.LocatableProperties;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import org.apache.struts2.StrutsConstants;
 
 public class LegacyPropertiesConfigurationProvider implements ConfigurationProvider {

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/config/NullResult.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/config/NullResult.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/config/NullResult.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/config/NullResult.java Fri Dec  2 16:33:03 2011
@@ -21,8 +21,8 @@
 
 package org.apache.struts2.config;
 
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.Result;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.Result;
 
 /**
  * Null result to get around annotation defaults that can't be null

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/config/PropertiesSettings.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/config/PropertiesSettings.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/config/PropertiesSettings.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/config/PropertiesSettings.java Fri Dec  2 16:33:03 2011
@@ -29,11 +29,11 @@ import java.util.Iterator;
 import org.apache.struts2.StrutsException;
 import org.apache.struts2.util.ClassLoaderUtils;
 
-import com.opensymphony.xwork2.util.location.LocatableProperties;
-import com.opensymphony.xwork2.util.location.Location;
-import com.opensymphony.xwork2.util.location.LocationImpl;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.location.LocatableProperties;
+import org.apache.struts2.xwork2.util.location.Location;
+import org.apache.struts2.xwork2.util.location.LocationImpl;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/config/Settings.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/config/Settings.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/config/Settings.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/config/Settings.java Fri Dec  2 16:33:03 2011
@@ -23,14 +23,13 @@ package org.apache.struts2.config;
 
 import java.util.Iterator;
 import java.util.Locale;
-import java.util.StringTokenizer;
 
 import org.apache.struts2.StrutsConstants;
 
-import com.opensymphony.xwork2.ObjectFactory;
-import com.opensymphony.xwork2.util.location.Location;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ObjectFactory;
+import org.apache.struts2.xwork2.util.location.Location;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/config/StrutsXmlConfigurationProvider.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/config/StrutsXmlConfigurationProvider.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/config/StrutsXmlConfigurationProvider.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/config/StrutsXmlConfigurationProvider.java Fri Dec  2 16:33:03 2011
@@ -33,15 +33,15 @@ import java.util.Map;
 
 import javax.servlet.ServletContext;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.config.ConfigurationException;
-import com.opensymphony.xwork2.config.providers.XmlConfigurationProvider;
-import com.opensymphony.xwork2.inject.ContainerBuilder;
-import com.opensymphony.xwork2.inject.Context;
-import com.opensymphony.xwork2.inject.Factory;
-import com.opensymphony.xwork2.util.location.LocatableProperties;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.config.ConfigurationException;
+import org.apache.struts2.xwork2.config.providers.XmlConfigurationProvider;
+import org.apache.struts2.xwork2.inject.ContainerBuilder;
+import org.apache.struts2.xwork2.inject.Context;
+import org.apache.struts2.xwork2.inject.Factory;
+import org.apache.struts2.xwork2.util.location.LocatableProperties;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * Override Xwork class so we can use an arbitrary config file
@@ -88,7 +88,7 @@ public class StrutsXmlConfigurationProvi
     }
     
     /* (non-Javadoc)
-     * @see com.opensymphony.xwork2.config.providers.XmlConfigurationProvider#register(com.opensymphony.xwork2.inject.ContainerBuilder, java.util.Properties)
+     * @see org.apache.struts2.xwork2.config.providers.XmlConfigurationProvider#register(org.apache.struts2.xwork2.inject.ContainerBuilder, java.util.Properties)
      */
     @Override
     public void register(ContainerBuilder containerBuilder, LocatableProperties props) throws ConfigurationException {
@@ -103,7 +103,7 @@ public class StrutsXmlConfigurationProvi
     }
 
     /* (non-Javadoc)
-     * @see com.opensymphony.xwork2.config.providers.XmlConfigurationProvider#init(com.opensymphony.xwork2.config.Configuration)
+     * @see org.apache.struts2.xwork2.config.providers.XmlConfigurationProvider#init(org.apache.struts2.xwork2.config.Configuration)
      */
     @Override
     public void loadPackages() {
@@ -116,7 +116,7 @@ public class StrutsXmlConfigurationProvi
      * Look for the configuration file on the classpath and in the file system
      *
      * @param fileName The file name to retrieve
-     * @see com.opensymphony.xwork2.config.providers.XmlConfigurationProvider#getConfigurationUrls
+     * @see org.apache.struts2.xwork2.config.providers.XmlConfigurationProvider#getConfigurationUrls
      */
     @Override
     protected Iterator<URL> getConfigurationUrls(String fileName) throws IOException {

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ActionContextCleanUp.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ActionContextCleanUp.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ActionContextCleanUp.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ActionContextCleanUp.java Fri Dec  2 16:33:03 2011
@@ -32,10 +32,10 @@ import javax.servlet.ServletResponse;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.util.profiling.UtilTimerStack;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.profiling.UtilTimerStack;
 
 /**
  * <!-- SNIPPET START: description -->

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/DefaultActionSupport.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/DefaultActionSupport.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/DefaultActionSupport.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/DefaultActionSupport.java Fri Dec  2 16:33:03 2011
@@ -26,7 +26,7 @@ import javax.servlet.http.HttpServletReq
 
 import org.apache.struts2.ServletActionContext;
 
-import com.opensymphony.xwork2.ActionSupport;
+import org.apache.struts2.xwork2.ActionSupport;
 
 /**
  * A simple action support class that sets properties to be able to serve
@@ -46,7 +46,7 @@ public class DefaultActionSupport extend
     }
 
     /* (non-Javadoc)
-     * @see com.opensymphony.xwork2.ActionSupport#execute()
+     * @see org.apache.struts2.xwork2.ActionSupport#execute()
      */
     public String execute() throws Exception {
         HttpServletRequest request = ServletActionContext.getRequest();

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/DefaultStaticContentLoader.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/DefaultStaticContentLoader.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/DefaultStaticContentLoader.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/DefaultStaticContentLoader.java Fri Dec  2 16:33:03 2011
@@ -20,10 +20,10 @@
  */
 package org.apache.struts2.dispatcher;
 
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.ClassLoaderUtil;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.ClassLoaderUtil;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import org.apache.struts2.StrutsConstants;
 import org.apache.struts2.dispatcher.ng.HostConfig;
 import org.apache.struts2.util.ClassLoaderUtils;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/Dispatcher.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/Dispatcher.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/Dispatcher.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/Dispatcher.java Fri Dec  2 16:33:03 2011
@@ -21,33 +21,33 @@
 
 package org.apache.struts2.dispatcher;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionProxy;
-import com.opensymphony.xwork2.ActionProxyFactory;
-import com.opensymphony.xwork2.ObjectFactory;
-import com.opensymphony.xwork2.Result;
-import com.opensymphony.xwork2.config.Configuration;
-import com.opensymphony.xwork2.config.ConfigurationException;
-import com.opensymphony.xwork2.config.ConfigurationManager;
-import com.opensymphony.xwork2.config.ConfigurationProvider;
-import com.opensymphony.xwork2.config.entities.InterceptorMapping;
-import com.opensymphony.xwork2.config.entities.InterceptorStackConfig;
-import com.opensymphony.xwork2.config.entities.PackageConfig;
-import com.opensymphony.xwork2.config.providers.XmlConfigurationProvider;
-import com.opensymphony.xwork2.inject.Container;
-import com.opensymphony.xwork2.inject.ContainerBuilder;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.interceptor.Interceptor;
-import com.opensymphony.xwork2.util.FileManager;
-import com.opensymphony.xwork2.util.LocalizedTextUtil;
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.ValueStackFactory;
-import com.opensymphony.xwork2.util.location.LocatableProperties;
-import com.opensymphony.xwork2.util.location.Location;
-import com.opensymphony.xwork2.util.location.LocationUtils;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.util.profiling.UtilTimerStack;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionProxy;
+import org.apache.struts2.xwork2.ActionProxyFactory;
+import org.apache.struts2.xwork2.ObjectFactory;
+import org.apache.struts2.xwork2.Result;
+import org.apache.struts2.xwork2.config.Configuration;
+import org.apache.struts2.xwork2.config.ConfigurationException;
+import org.apache.struts2.xwork2.config.ConfigurationManager;
+import org.apache.struts2.xwork2.config.ConfigurationProvider;
+import org.apache.struts2.xwork2.config.entities.InterceptorMapping;
+import org.apache.struts2.xwork2.config.entities.InterceptorStackConfig;
+import org.apache.struts2.xwork2.config.entities.PackageConfig;
+import org.apache.struts2.xwork2.config.providers.XmlConfigurationProvider;
+import org.apache.struts2.xwork2.inject.Container;
+import org.apache.struts2.xwork2.inject.ContainerBuilder;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.interceptor.Interceptor;
+import org.apache.struts2.xwork2.util.FileManager;
+import org.apache.struts2.xwork2.util.LocalizedTextUtil;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStackFactory;
+import org.apache.struts2.xwork2.util.location.LocatableProperties;
+import org.apache.struts2.xwork2.util.location.Location;
+import org.apache.struts2.xwork2.util.location.LocationUtils;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.profiling.UtilTimerStack;
 import freemarker.template.Template;
 import org.apache.struts2.ServletActionContext;
 import org.apache.struts2.StrutsConstants;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/FilterDispatcher.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/FilterDispatcher.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/FilterDispatcherCompatWeblogic61.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/FilterDispatcherCompatWeblogic61.java Fri Dec  2 16:33:03 2011
@@ -29,8 +29,8 @@ import javax.servlet.http.HttpSession;
 
 import org.apache.struts2.config.ServletContextSingleton;
 
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/HttpHeaderResult.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/HttpHeaderResult.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/HttpHeaderResult.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/HttpHeaderResult.java Fri Dec  2 16:33:03 2011
@@ -29,11 +29,11 @@ import javax.servlet.http.HttpServletRes
 
 import org.apache.struts2.ServletActionContext;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.Result;
-import com.opensymphony.xwork2.util.TextParseUtil;
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.Result;
+import org.apache.struts2.xwork2.util.TextParseUtil;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/PlainTextResult.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/PlainTextResult.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/PlainTextResult.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/PlainTextResult.java Fri Dec  2 16:33:03 2011
@@ -21,9 +21,9 @@
 
 package org.apache.struts2.dispatcher;
 
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 import javax.servlet.ServletContext;
 import javax.servlet.http.HttpServletResponse;
@@ -109,7 +109,7 @@ public class PlainTextResult extends Str
     }
 
     /* (non-Javadoc)
-     * @see org.apache.struts2.dispatcher.StrutsResultSupport#doExecute(java.lang.String, com.opensymphony.xwork2.ActionInvocation)
+     * @see org.apache.struts2.dispatcher.StrutsResultSupport#doExecute(java.lang.String, org.apache.struts2.xwork2.ActionInvocation)
      */
     protected void doExecute(String finalLocation, ActionInvocation invocation) throws Exception {
 

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ServletActionRedirectResult.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ServletActionRedirectResult.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ServletActionRedirectResult.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ServletActionRedirectResult.java Fri Dec  2 16:33:03 2011
@@ -27,10 +27,8 @@ import java.util.List;
 import org.apache.struts2.dispatcher.mapper.ActionMapper;
 import org.apache.struts2.dispatcher.mapper.ActionMapping;
 
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.util.reflection.ReflectionExceptionHandler;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.util.reflection.ReflectionExceptionHandler;
 
 /**
  * <!-- START SNIPPET: description -->
@@ -163,7 +161,7 @@ public class ServletActionRedirectResult
     }
 
     /**
-     * @see com.opensymphony.xwork2.Result#execute(com.opensymphony.xwork2.ActionInvocation)
+     * @see org.apache.struts2.xwork2.Result#execute(org.apache.struts2.xwork2.ActionInvocation)
      */
     public void execute(ActionInvocation invocation) throws Exception
     {

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ServletDispatcherResult.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ServletDispatcherResult.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ServletDispatcherResult.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ServletDispatcherResult.java Fri Dec  2 16:33:03 2011
@@ -21,9 +21,9 @@
 
 package org.apache.struts2.dispatcher;
 
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import org.apache.commons.lang.ObjectUtils;
 import org.apache.struts2.ServletActionContext;
 import org.apache.struts2.StrutsStatics;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ServletRedirectResult.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ServletRedirectResult.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ServletRedirectResult.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ServletRedirectResult.java Fri Dec  2 16:33:03 2011
@@ -21,14 +21,14 @@
 
 package org.apache.struts2.dispatcher;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.config.entities.ResultConfig;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.util.reflection.ReflectionException;
-import com.opensymphony.xwork2.util.reflection.ReflectionExceptionHandler;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.config.entities.ResultConfig;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.reflection.ReflectionException;
+import org.apache.struts2.xwork2.util.reflection.ReflectionExceptionHandler;
 import org.apache.struts2.ServletActionContext;
 import org.apache.struts2.dispatcher.mapper.ActionMapper;
 import org.apache.struts2.dispatcher.mapper.ActionMapping;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/StreamResult.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/StreamResult.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/StreamResult.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/StreamResult.java Fri Dec  2 16:33:03 2011
@@ -26,10 +26,10 @@ import java.io.OutputStream;
 
 import javax.servlet.http.HttpServletResponse;
 
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * <!-- START SNIPPET: description -->
@@ -215,7 +215,7 @@ public class StreamResult extends Struts
     }
 
     /**
-     * @see org.apache.struts2.dispatcher.StrutsResultSupport#doExecute(java.lang.String, com.opensymphony.xwork2.ActionInvocation)
+     * @see org.apache.struts2.dispatcher.StrutsResultSupport#doExecute(java.lang.String, org.apache.struts2.xwork2.ActionInvocation)
      */
     protected void doExecute(String finalLocation, ActionInvocation invocation) throws Exception {
 

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/StrutsRequestWrapper.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/StrutsRequestWrapper.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/StrutsRequestWrapper.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/StrutsRequestWrapper.java Fri Dec  2 16:33:03 2011
@@ -24,8 +24,8 @@ package org.apache.struts2.dispatcher;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletRequestWrapper;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/StrutsResultSupport.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/StrutsResultSupport.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/VelocityResult.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/VelocityResult.java Fri Dec  2 16:33:03 2011
@@ -21,12 +21,12 @@
 
 package org.apache.struts2.dispatcher;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import org.apache.struts2.ServletActionContext;
 import org.apache.struts2.StrutsConstants;
 import org.apache.struts2.views.JspSupportServlet;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/ActionMapper.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/ActionMapper.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/ActionMapper.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/ActionMapper.java Fri Dec  2 16:33:03 2011
@@ -23,7 +23,7 @@ package org.apache.struts2.dispatcher.ma
 
 import javax.servlet.http.HttpServletRequest;
 
-import com.opensymphony.xwork2.config.ConfigurationManager;
+import org.apache.struts2.xwork2.config.ConfigurationManager;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/ActionMapping.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/ActionMapping.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/ActionMapping.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/ActionMapping.java Fri Dec  2 16:33:03 2011
@@ -23,7 +23,7 @@ package org.apache.struts2.dispatcher.ma
 
 import java.util.Map;
 
-import com.opensymphony.xwork2.Result;
+import org.apache.struts2.xwork2.Result;
 
 /**
  * Simple class that holds the action mapping information used to invoke a

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/CompositeActionMapper.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/CompositeActionMapper.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/CompositeActionMapper.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/CompositeActionMapper.java Fri Dec  2 16:33:03 2011
@@ -28,11 +28,11 @@ import javax.servlet.http.HttpServletReq
 
 import org.apache.struts2.StrutsConstants;
 
-import com.opensymphony.xwork2.config.ConfigurationManager;
-import com.opensymphony.xwork2.inject.Container;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.config.ConfigurationManager;
+import org.apache.struts2.xwork2.inject.Container;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * <!-- START SNIPPET: description -->

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/DefaultActionMapper.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/DefaultActionMapper.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/DefaultActionMapper.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/DefaultActionMapper.java Fri Dec  2 16:33:03 2011
@@ -21,12 +21,12 @@
 
 package org.apache.struts2.dispatcher.mapper;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.config.Configuration;
-import com.opensymphony.xwork2.config.ConfigurationManager;
-import com.opensymphony.xwork2.config.entities.PackageConfig;
-import com.opensymphony.xwork2.inject.Container;
-import com.opensymphony.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.config.Configuration;
+import org.apache.struts2.xwork2.config.ConfigurationManager;
+import org.apache.struts2.xwork2.config.entities.PackageConfig;
+import org.apache.struts2.xwork2.inject.Container;
+import org.apache.struts2.xwork2.inject.Inject;
 import org.apache.struts2.RequestUtils;
 import org.apache.struts2.ServletActionContext;
 import org.apache.struts2.StrutsConstants;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/PrefixBasedActionMapper.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/PrefixBasedActionMapper.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/PrefixBasedActionMapper.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/PrefixBasedActionMapper.java Fri Dec  2 16:33:03 2011
@@ -1,8 +1,8 @@
 package org.apache.struts2.dispatcher.mapper;
 
-import com.opensymphony.xwork2.config.ConfigurationManager;
-import com.opensymphony.xwork2.inject.Container;
-import com.opensymphony.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.config.ConfigurationManager;
+import org.apache.struts2.xwork2.inject.Container;
+import org.apache.struts2.xwork2.inject.Inject;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.apache.struts2.StrutsConstants;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/Restful2ActionMapper.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/Restful2ActionMapper.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/Restful2ActionMapper.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/Restful2ActionMapper.java Fri Dec  2 16:33:03 2011
@@ -29,10 +29,10 @@ import javax.servlet.http.HttpServletReq
 
 import org.apache.struts2.StrutsConstants;
 
-import com.opensymphony.xwork2.config.ConfigurationManager;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.config.ConfigurationManager;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * <!-- START SNIPPET: description -->

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/RestfulActionMapper.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/RestfulActionMapper.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/RestfulActionMapper.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/RestfulActionMapper.java Fri Dec  2 16:33:03 2011
@@ -23,7 +23,6 @@ package org.apache.struts2.dispatcher.ma
 
 import java.net.URLDecoder;
 import java.util.HashMap;
-import java.util.Iterator;
 import java.util.Map;
 import java.util.StringTokenizer;
 
@@ -31,9 +30,9 @@ import javax.servlet.http.HttpServletReq
 
 import org.apache.struts2.RequestUtils;
 
-import com.opensymphony.xwork2.config.ConfigurationManager;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.config.ConfigurationManager;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/multipart/JakartaMultiPartRequest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/multipart/JakartaMultiPartRequest.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/multipart/JakartaMultiPartRequest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/multipart/JakartaMultiPartRequest.java Fri Dec  2 16:33:03 2011
@@ -21,9 +21,9 @@
 
 package org.apache.struts2.dispatcher.multipart;
 
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import org.apache.commons.fileupload.FileItem;
 import org.apache.commons.fileupload.FileUploadException;
 import org.apache.commons.fileupload.RequestContext;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/multipart/MultiPartRequestWrapper.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/multipart/MultiPartRequestWrapper.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/multipart/MultiPartRequestWrapper.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/multipart/MultiPartRequestWrapper.java Fri Dec  2 16:33:03 2011
@@ -34,8 +34,8 @@ import javax.servlet.http.HttpServletReq
 
 import org.apache.struts2.dispatcher.StrutsRequestWrapper;
 
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ng/InitOperations.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ng/InitOperations.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ng/InitOperations.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ng/InitOperations.java Fri Dec  2 16:33:03 2011
@@ -20,8 +20,8 @@
  */
 package org.apache.struts2.dispatcher.ng;
 
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import org.apache.struts2.dispatcher.Dispatcher;
 import org.apache.struts2.dispatcher.StaticContentLoader;
 import org.apache.struts2.util.ClassLoaderUtils;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ng/PrepareOperations.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ng/PrepareOperations.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ng/PrepareOperations.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ng/PrepareOperations.java Fri Dec  2 16:33:03 2011
@@ -31,11 +31,11 @@ import javax.servlet.ServletContext;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.ValueStackFactory;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStackFactory;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 import java.io.IOException;
 import java.util.HashMap;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/impl/StrutsActionProxy.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/impl/StrutsActionProxy.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/impl/StrutsActionProxy.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/impl/StrutsActionProxy.java Fri Dec  2 16:33:03 2011
@@ -23,11 +23,9 @@
 
 package org.apache.struts2.impl;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.DefaultActionProxy;
-
-import java.util.Map;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.DefaultActionProxy;
 
 public class StrutsActionProxy extends DefaultActionProxy {
 

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/impl/StrutsActionProxyFactory.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/impl/StrutsActionProxyFactory.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/impl/StrutsActionProxyFactory.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/impl/StrutsActionProxyFactory.java Fri Dec  2 16:33:03 2011
@@ -23,11 +23,9 @@
 
 package org.apache.struts2.impl;
 
-import java.util.Map;
-
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.ActionProxy;
-import com.opensymphony.xwork2.DefaultActionProxyFactory;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.ActionProxy;
+import org.apache.struts2.xwork2.DefaultActionProxyFactory;
 
 public class StrutsActionProxyFactory extends DefaultActionProxyFactory {
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/FilterDispatcher.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/FilterDispatcher.java Fri Dec  2 16:33:03 2011
@@ -43,15 +43,13 @@ import org.apache.struts2.dispatcher.map
 import org.apache.struts2.dispatcher.ng.filter.FilterHostConfig;
 import org.apache.struts2.util.ClassLoaderUtils;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.config.Configuration;
-import com.opensymphony.xwork2.config.ConfigurationProvider;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.ValueStackFactory;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.util.profiling.UtilTimerStack;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStackFactory;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.profiling.UtilTimerStack;
 
 /**
  * Master filter for Struts that handles four distinct
@@ -121,7 +119,7 @@ import com.opensymphony.xwork2.util.prof
  * <li><b>actionPackages</b> - a comma-delimited list of Java packages to scan for Actions.</li>
  * <p/>
  * <li><b>configProviders</b> - a comma-delimited list of Java classes that implement the
  * {@link ConfigurationProvider} interface that should be used for building the {@link Configuration}.</li>
  * <p/>
  * <li><b>loggerFactory</b> - The class name of the {@link LoggerFactory} implementation.</li>
  * <p/>
@@ -121,7 +119,7 @@ import com.opensymphony.xwork2.util.prof
  * <p/>
  * <li><b>configProviders</b> - a comma-delimited list of Java classes that implement the
- * {@link ConfigurationProvider} interface that should be used for building the {@link Configuration}.</li>
+ * {@link org.apache.struts2.xwork2.config.ConfigurationProvider} interface that should be used for building the {@link org.apache.struts2.xwork2.config.Configuration}.</li>
  * <p/>
  * <li><b>loggerFactory</b> - The class name of the {@link LoggerFactory} implementation.</li>

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/FilterDispatcherCompatWeblogic61.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/FilterDispatcherCompatWeblogic61.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/StrutsResultSupport.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/StrutsResultSupport.java Fri Dec  2 16:33:03 2011
@@ -26,11 +26,11 @@ import java.net.URLEncoder;
 
 import org.apache.struts2.StrutsStatics;
 
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.Result;
-import com.opensymphony.xwork2.util.TextParseUtil;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.Result;
+import org.apache.struts2.xwork2.util.TextParseUtil;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 
 /**
@@ -43,7 +43,7 @@ import com.opensymphony.xwork2.util.logg
  * <ul>
  * <li>location - the location to go to after execution (could be a jsp page or another action).
  * It can be parsed as per the rules definied in the
- * {@link TextParseUtil#translateVariables(java.lang.String, com.opensymphony.xwork2.util.ValueStack) translateVariables}
+ * {@link TextParseUtil#translateVariables(java.lang.String, org.apache.struts2.xwork2.util.ValueStack) translateVariables}
  * method</li>
  * <li>parse - true by default. If set to false, the location param will not be parsed for expressions</li>
  * <li>encode - false by default. If set to false, the location param will not be url encoded. This only have effect when parse is true</li>
@@ -95,11 +95,11 @@ import com.opensymphony.xwork2.util.logg
  *      &lt;result-type name="myresult" class="com.foo.MyResult" /&gt;
  *  &lt;/result-types&gt;</pre>
  * <p/>
  * Please see the {@link com.opensymphony.xwork2.Result} class for more info on Results in general.
  *
  * <!-- END SNIPPET: example -->
  *
- * @see com.opensymphony.xwork2.Result
+ * @see org.apache.struts2.xwork2.Result
  */
 public abstract class StrutsResultSupport implements Result, StrutsStatics {
 
@@ -95,11 +95,11 @@ import com.opensymphony.xwork2.util.logg
  *  &lt;/result-types&gt;</pre>
  * <p/>
- * Please see the {@link com.opensymphony.xwork2.Result} class for more info on Results in general.
+ * Please see the {@link org.apache.struts2.xwork2.Result} class for more info on Results in general.
  *
  * <!-- END SNIPPET: example -->

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/VelocityResult.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/VelocityResult.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================